civic\_scraper.platforms.civic\_plus package
============================================

Submodules
----------

civic\_scraper.platforms.civic\_plus.parser module
--------------------------------------------------

.. automodule:: civic_scraper.platforms.civic_plus.parser
   :members:
   :undoc-members:
   :show-inheritance:

civic\_scraper.platforms.civic\_plus.site module
------------------------------------------------

.. automodule:: civic_scraper.platforms.civic_plus.site
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: civic_scraper.platforms.civic_plus
   :members:
   :undoc-members:
   :show-inheritance:
